@@ -1,22 +1,9 @@
-/***************************************************************************
- *   Copyright (C) 2012-2016 by Eike Hein <hein@kde.org>                   *
- *   Copyright (c) 2020 by Nate Graham <nate@kde.org>                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2012-2016 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2020 Nate Graham <nate@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 .import org.kde.taskmanager 0.1 as TaskManager
 .import org.kde.plasma.core 2.0 as PlasmaCore // Needed by TaskManager
@@ -59,7 +46,7 @@ function activateNextPrevTask(anchor, next) {
                 }
 
                 for (var j = 0; j < tasksModel.rowCount(modelIndex); ++j) {
-                    var childModelIndex = tasksModel.makeModelIndex(i, j);
+                    const childModelIndex = tasksModel.makeModelIndex(i, j);
                     if (!task.m.IsHidden) {
                         taskIndexList.push(childModelIndex);
                     }
