@@ -216,7 +216,6 @@ QHash<int, QByteArray> FolderModel::staticRoleNames()
     roleNames[Qt::DisplayRole] = "display";
     roleNames[Qt::DecorationRole] = "decoration";
     roleNames[BlankRole] = "blank";
-    roleNames[OverlaysRole] = "overlays";
     roleNames[SelectedRole] = "selected";
     roleNames[IsDirRole] = "isDir";
     roleNames[IsLinkRole] = "isLink";
@@ -1297,9 +1296,6 @@ QVariant FolderModel::data(const QModelIndex &index, int role) const
 
     if (role == BlankRole) {
         return m_dragIndexes.contains(index);
-    } else if (role == OverlaysRole) {
-        const KFileItem item = itemForIndex(index);
-        return item.overlays();
     } else if (role == SelectedRole) {
         return m_selectionModel->isSelected(index);
     } else if (role == IsDirRole) {
