@@ -151,7 +151,9 @@ bool XkbHelper::initializeKeyboardLayouts(KeyboardConfig &config)
         }
     }
     if (config.resetOldXkbOptions) {
+        // Pass -option "" to clear previously set options
         setxkbmapCommandArguments.append(QStringLiteral("-option"));
+        setxkbmapCommandArguments.append(QStringLiteral(""));
     }
     if (!config.xkbOptions.isEmpty()) {
         setxkbmapCommandArguments.append(QStringLiteral("-option"));
